import sys
import pygame
import random

# Window Properties
TITLE = 'SPACE ADVENTURE'
WIDTH = 1000
HEIGHT = 800

# Initialize Pygame
pygame.init()

# Set up the window
custom_font = pygame.font.Font(pygame.font.match_font('arial'), 25)
window_surface = pygame.display.set_mode((WIDTH, HEIGHT), 0, 32)
pygame.display.set_caption(TITLE)

space_background = pygame.image.load("images/space background (3).png"). convert()
mars_background = pygame.image.load("images/mars_backgorund.png").convert()
moon_background = pygame.image.load("images/moon background.png").convert()
venus_background = pygame.image.load("images/Venus background.png").convert()
moon_cave_background = pygame.image.load("images/lunar_cave.jpeg").convert()
planet_mars = pygame.image.load("images/mars-removebg-preview.png").convert_alpha()
planet_moon = pygame.image.load("images/moon-png--0.png").convert_alpha()
planet_venus = pygame.image.load("images/venus-PhotoRoom.png-PhotoRoom.png").convert_alpha()


# Scale the planet images to the same size
planet_size = (250, 250)
planet_size2 = (350, 260)
planet_mars = pygame.transform.scale(planet_mars, planet_size)
planet_moon = pygame.transform.scale(planet_moon, planet_size2)
planet_venus = pygame.transform.scale(planet_venus, planet_size)

# Define the clickable areas (rectangles) for the planets and choices
mars_rect = pygame.Rect(75, 350, planet_size[0], planet_size[1])
moon_rect = pygame.Rect(350, 350, planet_size2[0], planet_size2[1])
venus_rect = pygame.Rect(690, 350, planet_size[0], planet_size[1])
enter_cave_rect = pygame.Rect(400, 525, 200, 50)  # Enter Cave button
return_ship_rect = pygame.Rect(400, 575, 200, 50)
study_artifact_rect = pygame.Rect(400, 525, 200, 50)  # Study Artifact button
argue_captain_rect = pygame.Rect(400, 575, 200, 50)  # Argue with Co-Captain button# Return to Ship button
# Rectangles for Mars event options
enter_canyons_rect = pygame.Rect(400, 500, 300, 50)  # Adjusted size and position
investigate_signal_rect = pygame.Rect(400, 560, 300, 50)  # Adjusted size and position
setup_station_rect = pygame.Rect(400, 620, 300, 50)  # Adjusted size and position
search_life_rect = pygame.Rect(400, 680, 300, 50)  # Adjusted size and position

# Game States
game_state = 'intro'
artifact_options = ['silicon disc with goodwill messages from 73 countries on the Moon during the Apollo 11 mission in 1969!']
    
def render_text(text, centered=False, y_offset=0):
    text_surface = custom_font.render(text, True, (255, 255, 255))
    if centered:
        text_rect = text_surface.get_rect(center=(WIDTH // 2, 50 + y_offset))
    else:
        text_rect = text_surface.get_rect(topleft=(100, 450 + y_offset))
    window_surface.blit(text_surface, text_rect)


# Function to display the intro story
def draw_intro():
    window_surface.blit(pygame.transform.scale(space_background, (WIDTH, HEIGHT)), (0, 0))

    # Define the intro text with line breaks
    intro_text = [
        "You are the captain of a starship on an exploration mission.",
        "Your mission: To boldly go where no one has gone before.",
        "Choose your destination wisely, and may the stars guide your way."
    ]

    # Render and display each line of text
    y_offset = 200  
    for line in intro_text:
        render_text(line, True, y_offset)
        y_offset += 50  

# Function to display planet choices
def draw_planet_choice():
    window_surface.blit(pygame.transform.scale(space_background, (WIDTH, HEIGHT)), (0, 0))

    # Define the positions of planet images and their names
    planets = [
        ("Mars", planet_mars, mars_rect.topleft),
        ("Moon", planet_moon, moon_rect.topleft),
        ("Venus", planet_venus, venus_rect.topleft)
    ]

    for planet_name, planet_image, image_position in planets:
        # Calculate the position for the planet name (above the planet image)
        name_x = image_position[0] + planet_image.get_width() // 2
        name_y = image_position[1] - 20  

        window_surface.blit(planet_image, image_position)
        text_surface = custom_font.render(planet_name, True, (255, 255, 255))
        text_rect = text_surface.get_rect(center=(name_x, name_y))
        window_surface.blit(text_surface, text_rect)

# Function to handle planet choice clicks
def on_mouse_down(pos):
    global game_state
    if game_state == 'planet_choice':
        if mars_rect.collidepoint(pos):
            game_state = 'mars_event'
        elif moon_rect.collidepoint(pos):
            game_state = 'moon_event'
        elif venus_rect.collidepoint(pos):
            game_state = 'venus_event'
            
    elif game_state == 'mars_event':
        if enter_canyons_rect.collidepoint(pos):
            game_state = 'oxygen_depletion'
        elif investigate_signal_rect.collidepoint(pos):
            game_state = 'investigate_signal'  
        elif setup_station_rect.collidepoint(pos):
            game_state = 'setup_station' 
        elif search_life_rect.collidepoint(pos):
            game_state = 'search_life'
       
    elif game_state == 'oxygen_depletion':
        game_state = 'planet_choice'
        
    elif game_state == 'investigate_signal':
        game_state = 'intro'
        
    elif game_state == 'setup_station':
        game_state = 'intro'
        
    elif game_state == 'search_life':
        game_state = 'intro'
        
    elif game_state == 'moon_event':
        if enter_cave_rect.collidepoint(pos):
            game_state = 'moon_cave_event'
        elif return_ship_rect.collidepoint(pos):
            game_state = 'planet_choice'
            
    elif game_state == 'moon_cave_event':
        if study_artifact_rect.collidepoint(pos):
            game_state = 'study_artifact'
        elif argue_captain_rect.collidepoint(pos):
            game_state = 'argue_captain'
            
    elif game_state in ['study_artifact', 'argue_captain']:
        game_state = 'intro' if game_state == 'argue_captain' else 'planet_choice'
        
    elif game_state == 'venus_event':
        game_state = 'intro'
    
  
# Function for Mars event
def mars_event():
    window_surface.blit(mars_background, (0, 0))
    render_text("Welcome to Mars!", True, 200)
    render_text("Enter Ancient Martian Canyons", True, 450)
    render_text("Investigate a Mysterious Signal", True, 510)
    render_text("Set Up a Research Station", True, 570)
    render_text("Search for Signs of Past Life", True, 630)


def oxygen_depletion_event():
    window_surface.blit(mars_background, (0, 0))
    render_text("Oh no! You have run out of oxygen. RETURN TO THE SPACESHIP IMMEDIATELY!", True, 200)

# Function for Mars event - Investigate a Mysterious Signal
def investigate_signal_event():
    window_surface.blit(mars_background, (0, 0))
    render_text("You investigated a mysterious signal...", True, 200)
    render_text("Suddenly, an alien spaceship appeared and you were taken.", True, 250)
    render_text("GAME OVER - Click anywhere to return to the intro.", True, 300)

# Function for Mars event - Set Up a Research Station
def setup_station_event():
    window_surface.blit(mars_background, (0, 0))
    render_text("Congratulations! You successfully set up a research station on Mars.", True, 200)
    render_text("You've won the game!", True, 250)
    render_text("Click anywhere to replay or return to the intro.", True, 300)

# Function for Mars event - Search for Signs of Past Life
def search_life_event():
    window_surface.blit(mars_background, (0, 0))
    render_text("As you search for signs of past life, you begin to feel a strange presence...", True, 200)
    render_text("You are haunted by the ghosts of previous astronauts who died here.", True, 250)
    render_text("GAME OVER - Click anywhere to return to the intro.", True, 300)

# Function for Moon event
def moon_event():
    window_surface.blit(pygame.transform.scale(moon_background, (WIDTH, HEIGHT)), (0, 0))
    render_text("Enter Cave", True, 500)  # Placeholder for the enter cave option
    render_text("Return to Ship", True, 550)  # Placeholder for the return to ship option

# Function for Venus event
def venus_event():
    window_surface.blit(venus_background, (0, 0))
    render_text("UH OH! Game over!", True, 200)
    render_text("You are now a space pancake", True, 250)
    render_text("The temperature in Venus is 867 degrees F!", True, 300)

# Function for Moon Cave 

def moon_cave_event():
    window_surface.blit(pygame.transform.scale(moon_cave_background, (WIDTH, HEIGHT)), (0, 0))
    render_text("You are now in the Moon Cave! Do you:", True, 200)
    render_text("Study an Artifact", True, 500)  # Option to study an artifact
    render_text("Argue with Co-Captain", True, 550)  # Op
    
def study_artifact_event():
    window_surface.blit(pygame.transform.scale(moon_cave_background, (WIDTH, HEIGHT)), (0, 0))
    artifact = random.choice(artifact_options)
    render_text("You found a silicon disc with goodwill", True, 200)
    render_text('messages from 73 countries on the Moon during the Apollo 11 mission in 1969!', True, 250 )
    render_text("Click to return to planet choice...", True, 500)
# Function for handling clicks within Moon Cave event
def argue_captain_event():
    window_surface.blit(pygame.transform.scale(moon_cave_background, (WIDTH, HEIGHT)), (0, 0))
    render_text("You argued with your co-captain...", True, 200)
    render_text("The argument escalated and ended tragically.", True, 250)
    render_text("GAME OVER - Click anywhere to return to the intro.", True, 300)

# Start the game loop
running = True
while running:
    for event in pygame.event.get():
        if event.type == pygame.QUIT:
            running = False
        elif event.type == pygame.MOUSEBUTTONDOWN:
            if game_state == 'intro':
                game_state = 'planet_choice'
            else:
                on_mouse_down(event.pos)

    if game_state == 'intro':
        draw_intro()
    elif game_state == 'planet_choice':
        draw_planet_choice()
    elif game_state == 'mars_event':
        mars_event()
    elif game_state == 'moon_event':
        moon_event()
    elif game_state == 'venus_event':
        venus_event()
    elif game_state == 'moon_cave_event':
        moon_cave_event()
    elif game_state == 'study_artifact':
        study_artifact_event()
    elif game_state == 'argue_captain':
        argue_captain_event()
    elif game_state == 'oxygen_depletion':
        oxygen_depletion_event()
    elif game_state == 'investigate_signal':
        investigate_signal_event()
    elif game_state == 'setup_station':
        setup_station_event()
    elif game_state == 'search_life':
        search_life_event()
        
    pygame.display.update()

pygame.quit()
sys.exit()
